use std::{net::SocketAddr, str::FromStr};
use warp::Filter;

mod infra;
mod service;

// TODO: Configurable
const SERVE_ADDR: &str = "127.0.0.1:3030";

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    pretty_env_logger::try_init()?;

    // TODO: use CORS correctly
    let cors = warp::cors()
        .allow_any_origin()
        .allow_credentials(true)
        .allow_header("content-type")
        .allow_method("GET");

    let deck = warp::path!("deck" / String)
        .map(service::deck_service)
        .with(cors.clone());

    // TODO: cards服务暂时仅支持单卡查询
    let cards = warp::path!("cards" / String)
        .map(service::cards_service)
        .with(cors);

    // TODO: 模块化
    let images = warp::path("images").and(warp::fs::dir("./images/"));

    warp::serve(deck.or(cards).or(images))
        .run(SocketAddr::from_str(SERVE_ADDR)?)
        .await;

    Ok(())
}
